@@ -208,7 +208,10 @@ QList<PipeWireBaseEncodedStream::Encoder> PipeWireBaseEncodedStream::suggestedEn
     QList<PipeWireBaseEncodedStream::Encoder> ret = {PipeWireBaseEncodedStream::VP8,
                                                      PipeWireBaseEncodedStream::VP9,
                                                      PipeWireBaseEncodedStream::H264Main,
-                                                     PipeWireBaseEncodedStream::H264Baseline};
+                                                     PipeWireBaseEncodedStream::H264Baseline,
+                                                     PipeWireBaseEncodedStream::WebP,
+                                                     PipeWireBaseEncodedStream::Gif,
+                                                    };
     auto removeUnavailableEncoders = [&vaapi](const PipeWireBaseEncodedStream::Encoder &encoder) {
         switch (encoder) {
         case PipeWireBaseEncodedStream::VP8:
@@ -227,6 +230,10 @@ QList<PipeWireBaseEncodedStream::Encoder> PipeWireBaseEncodedStream::suggestedEn
             } else {
                 return !(avcodec_find_encoder_by_name("libx264") || avcodec_find_encoder_by_name("libopenh264"));
             }
+        case PipeWireBaseEncodedStream::WebP:
+            return !avcodec_find_encoder_by_name("libwebp");
+        case PipeWireBaseEncodedStream::Gif:
+            return !avcodec_find_encoder_by_name("gif");
         default:
             return true;
         }
