@@ -36,6 +36,8 @@ public:
         VP9,
         H264Main,
         H264Baseline,
+        WebP,
+        Gif,
     };
     Q_ENUM(Encoder)
 
@@ -52,6 +54,18 @@ public:
     void setMaxFramerate(const Fraction &framerate);
     void setMaxFramerate(quint32 numerator, quint32 denominator = 1);
 
+    /**
+     * Defines how many frames are kept in the encoding buffer.
+     * New frames after the buffer is full will be dropped.
+     *
+     * This needs to be high enough for intra-frame analysis.
+     * The default value is 50.
+     *
+     * There is a minimum value of 3.
+     */
+    void setMaxPendingFrames(int maxBufferSize);
+    int maxBufferSize() const;
+
     bool isActive() const;
     void setActive(bool active);
 
@@ -90,17 +104,28 @@ public:
     /// Returns the encoders that are tested to work, sorted by preference
     QList<PipeWireBaseEncodedStream::Encoder> suggestedEncoders() const;
 
+    enum EncodingPreference {
+        NoPreference, ///< Default settings, good for most usecases
+        Quality, ///< A bit slower than default, but more consistent bitrate, use for high quality
+        Speed, ///< Encode as fast as possible and use zerolatency tune, good for streaming
+        Size, ///< Slowest encoding but reduces the size of the file
+    };
+    Q_ENUM(EncodingPreference);
+    void setEncodingPreference(EncodingPreference profile);
+
 Q_SIGNALS:
     void activeChanged(bool active);
     void nodeIdChanged(uint nodeId);
     void fdChanged(uint fd);
     void errorFound(const QString &error);
     void maxFramerateChanged();
+    void maxPendingFramesChanged();
     void stateChanged();
     void encoderChanged();
 
 protected:
     virtual std::unique_ptr<PipeWireProduce> makeProduce() = 0;
+    EncodingPreference encodingPreference();
 
     void refresh();
     QScopedPointer<PipeWireEncodedStreamPrivate> d;
